@@ -24,7 +24,7 @@ use warnings;
 no warnings;
 use vars qw($VERSION);
 
-$VERSION = '2.08';
+$VERSION = '2.09';
 
 use Carp qw(carp croak);
 use File::Basename qw(dirname);
@@ -467,7 +467,23 @@ Added in 1.21.
 
 =cut
 
-sub perls { keys %{ $_[0]->{perls} } }
+sub perls {
+    my $self = shift;
+
+    my @perls = keys %{$self->{perls}};
+
+    # Sort them
+    @perls =
+	map  { $_->[0] }
+	sort { $a->[2] <=> $b->[2] || $a->[3] <=> $b->[3] || $a->[0] cmp $b->[0] }
+	map  { [ $_, (m/(perl5\.(?|([0-9]{3})_?([0-9]{2})|([0-9]{1,2})\.([0-9]+)))/) ] }
+	map  { (m{.*/(.*)}) }
+	grep { -x $_ }
+	@perls;
+
+    warn "Testing with ", scalar @perls, " versions of perl\n";
+    return @perls;
+    }
 
 =item add_a_perl( PATH )
 
